@@ -20,7 +20,7 @@ import nipype
 import nipype.interfaces.io as nio
 from nipype.interfaces.base.traits_extension import isdefined
 from nipype.interfaces.base import Undefined, TraitError
-from nipype.utils.filemanip import dist_is_editable
+from nipype.utils.filemanip import dist_is_editable, FileExistsError
 
 # Check for boto
 noboto = False
@@ -524,7 +524,7 @@ def test_datafinder_unpack(tmpdir):
 
     df = nio.DataFinder()
     df.inputs.root_paths = outdir
-    df.inputs.match_regex = '.+/(?P<basename>.+)\.txt'
+    df.inputs.match_regex = r'.+/(?P<basename>.+)\.txt'
     df.inputs.unpack_single = True
     result = df.run()
     print(result.outputs.out_paths)
@@ -581,8 +581,6 @@ def test_jsonsink(tmpdir, inputs_attributes):
 # There are three reasons these tests will be skipped:
 @pytest.mark.skipif(not have_pybids,
                     reason="Pybids is not installed")
-@pytest.mark.skipif(sys.version_info < (3, 0),
-                    reason="Pybids no longer supports Python 2")
 @pytest.mark.skipif(not dist_is_editable('pybids'),
                     reason="Pybids is not installed in editable mode")
 def test_bids_grabber(tmpdir):
@@ -591,15 +589,13 @@ def test_bids_grabber(tmpdir):
     bg.inputs.base_dir = os.path.join(datadir, 'ds005')
     bg.inputs.subject = '01'
     results = bg.run()
-    assert 'sub-01_T1w.nii.gz' in map(os.path.basename, results.outputs.anat)
+    assert 'sub-01_T1w.nii.gz' in map(os.path.basename, results.outputs.T1w)
     assert 'sub-01_task-mixedgamblestask_run-01_bold.nii.gz' in \
-        map(os.path.basename, results.outputs.func)
+        map(os.path.basename, results.outputs.bold)
 
 
 @pytest.mark.skipif(not have_pybids,
                     reason="Pybids is not installed")
-@pytest.mark.skipif(sys.version_info < (3, 0),
-                    reason="Pybids no longer supports Python 2")
 @pytest.mark.skipif(not dist_is_editable('pybids'),
                     reason="Pybids is not installed in editable mode")
 def test_bids_fields(tmpdir):
@@ -607,15 +603,13 @@ def test_bids_fields(tmpdir):
     bg = nio.BIDSDataGrabber(infields = ['subject'], outfields = ['dwi'])
     bg.inputs.base_dir = os.path.join(datadir, 'ds005')
     bg.inputs.subject = '01'
-    bg.inputs.output_query['dwi'] = dict(modality='dwi')
+    bg.inputs.output_query['dwi'] = dict(datatype='dwi')
     results = bg.run()
     assert 'sub-01_dwi.nii.gz' in map(os.path.basename, results.outputs.dwi)
 
 
 @pytest.mark.skipif(not have_pybids,
                     reason="Pybids is not installed")
-@pytest.mark.skipif(sys.version_info < (3, 0),
-                    reason="Pybids no longer supports Python 2")
 @pytest.mark.skipif(not dist_is_editable('pybids'),
                     reason="Pybids is not installed in editable mode")
 def test_bids_infields_outfields(tmpdir):
@@ -633,9 +627,9 @@ def test_bids_infields_outfields(tmpdir):
     for outfield in outfields:
         assert(outfield in bg._outputs().traits())
 
-    # now try without defining outfields, we should get anat and func for free
+    # now try without defining outfields
     bg = nio.BIDSDataGrabber()
-    for outfield in ['anat', 'func']:
+    for outfield in ['T1w', 'bold']:
         assert outfield in bg._outputs().traits()
 
 
@@ -686,3 +680,26 @@ def test_SSHDataGrabber(tmpdir):
             .check(file=True, exists=True)) # exists?
 
     old_cwd.chdir()
+
+
+def test_ExportFile(tmp_path):
+    testin = tmp_path / 'in.txt'
+    testin.write_text('test string')
+    i = nio.ExportFile()
+    i.inputs.in_file = str(testin)
+    i.inputs.out_file = str(tmp_path / 'out.tsv')
+    i.inputs.check_extension = True
+    with pytest.raises(RuntimeError):
+        i.run()
+    i.inputs.check_extension = False
+    i.run()
+    assert (tmp_path / 'out.tsv').read_text() == 'test string'
+    i.inputs.out_file = str(tmp_path / 'out.txt')
+    i.inputs.check_extension = True
+    i.run()
+    assert (tmp_path / 'out.txt').read_text() == 'test string'
+    with pytest.raises(FileExistsError):
+        i.run()
+    i.inputs.clobber = True
+    i.run()
+    assert (tmp_path / 'out.txt').read_text() == 'test string'
