@@ -16,11 +16,10 @@ anatfile = os.path.join(basedir, 'data', 'structural.nii')
 template = funcfile
 transfm = funcfile
 
-
-from . import decorators as dec
+from . import decorators
 from .utils import package_check, TempFATFS
 
-skipif = dec.skipif
+skipif = decorators.dec.skipif
 
 
 def example_data(infile='functional.nii'):
